@@ -19,23 +19,23 @@ os_release = OsReleaseFile('/etc/lsb-release')
 # OS release codename and snapshot of version 0.9-2~1
 if os_release['DISTRIB_ID'] == 'Ubuntu':
     os_codename = os_release['DISTRIB_CODENAME']
-    snap_header_0_9 = r'^test-package\s\(0.9-1ubuntu1~1\.gbp([0-9a-f]{6})\)\sUNRELEASED;\surgency=low'
+    snap_header_0_9 = r'^test-package\s\(0.9-1ubuntu1~1\.gbp([0-9a-f]{6})\)\sUNRELEASED;\surgency=medium'
     new_version_0_9 = '0.9-1ubuntu1'
 else:
     os_codename = 'unstable'
-    snap_header_0_9 = r'^test-package\s\(0.9-2~1\.gbp([0-9a-f]{6})\)\sUNRELEASED;\surgency=low'
+    snap_header_0_9 = r'^test-package\s\(0.9-2~1\.gbp([0-9a-f]{6})\)\sUNRELEASED;\surgency=medium'
     new_version_0_9 = '0.9-2'
 # Snapshot of version 1.0-1~1
-snap_header_1 = r'^test-package\s\(1.0-1~1\.gbp([0-9a-f]{6})\)\sUNRELEASED;\surgency=low'
+snap_header_1 = r'^test-package\s\(1.0-1~1\.gbp([0-9a-f]{6})\)\sUNRELEASED;\surgency=medium'
 # Snapshot of version 1.0-1~2
-snap_header_1_2 = r'^test-package\s\(1.0-1~2\.gbp([0-9a-f]{6})\)\sUNRELEASED;\surgency=low'
+snap_header_1_2 = r'^test-package\s\(1.0-1~2\.gbp([0-9a-f]{6})\)\sUNRELEASED;\surgency=medium'
 
 snap_mark = r'\s{2}\*{2}\sSNAPSHOT\sbuild\s@'
 
 deb_tag = "debian/0.9-1"
 deb_tag_msg = "Pre stable release version 0.9-1"
 
-cl_debian = """test-package (0.9-1) unstable; urgency=low
+cl_debian = """test-package (0.9-1) unstable; urgency=medium
 
   [ Debian Maintainer ]
   * New pre stable upstream release
@@ -85,7 +85,7 @@ class TestScriptDch(DebianGitTestRepo):
     def test_dch_main_new_upstream_version(self):
         """Test dch.py like git-dch script does: new upstream version"""
         lines = self.run_dch()
-        self.assertEqual("test-package (1.0-1) UNRELEASED; urgency=low\n", lines[0])
+        self.assertEqual("test-package (1.0-1) UNRELEASED; urgency=medium\n", lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
 
@@ -93,7 +93,7 @@ class TestScriptDch(DebianGitTestRepo):
         """Test dch.py like git-dch script does: new upstream version - release"""
         options = ["--release"]
         lines = self.run_dch(options)
-        self.assertEqual("test-package (1.0-1) %s; urgency=low\n" % os_codename, lines[0])
+        self.assertEqual("test-package (1.0-1) %s; urgency=medium\n" % os_codename, lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
 
@@ -101,7 +101,7 @@ class TestScriptDch(DebianGitTestRepo):
         """Test dch.py like git-dch script does: new upstream version - guess last commit"""
         options = ["--auto"]
         lines = self.run_dch(options)
-        self.assertEqual("test-package (1.0-1) UNRELEASED; urgency=low\n", lines[0])
+        self.assertEqual("test-package (1.0-1) UNRELEASED; urgency=medium\n", lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
 
@@ -170,7 +170,7 @@ class TestScriptDch(DebianGitTestRepo):
         """Test dch.py like git-dch script does: new upstream version - auto - release"""
         options = ["--auto", "--release"]
         lines = self.run_dch(options)
-        self.assertEqual("test-package (1.0-1) %s; urgency=low\n" % os_codename, lines[0])
+        self.assertEqual("test-package (1.0-1) %s; urgency=medium\n" % os_codename, lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
 
@@ -196,7 +196,7 @@ class TestScriptDch(DebianGitTestRepo):
         """Test dch.py like git-dch script does: new upstream version - set distribution"""
         options = ["--distribution=testing", "--force-distribution"]
         lines = self.run_dch(options)
-        self.assertEqual("test-package (1.0-1) testing; urgency=low\n", lines[0])
+        self.assertEqual("test-package (1.0-1) testing; urgency=medium\n", lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
 
@@ -204,7 +204,7 @@ class TestScriptDch(DebianGitTestRepo):
         """Test dch.py like git-dch script does: new upstream version - release - set distribution"""
         options = ["--release", "--distribution=testing", "--force-distribution"]
         lines = self.run_dch(options)
-        self.assertEqual("test-package (1.0-1) testing; urgency=low\n", lines[0])
+        self.assertEqual("test-package (1.0-1) testing; urgency=medium\n", lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
 
@@ -306,7 +306,7 @@ class TestScriptDch(DebianGitTestRepo):
         self.repo.create_tag("debian/0.9-1", msg="Pre stable release version 0.9-1", commit="HEAD~2")
         self.repo.delete_tag("upstream/1.0")
         lines = self.run_dch()
-        self.assertEqual("test-package (%s) UNRELEASED; urgency=low\n" % new_version_0_9, lines[0])
+        self.assertEqual("test-package (%s) UNRELEASED; urgency=medium\n" % new_version_0_9, lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
 
@@ -315,7 +315,7 @@ class TestScriptDch(DebianGitTestRepo):
         self.repo.delete_tag("upstream/1.0")
         options = ["--release"]
         lines = self.run_dch(options)
-        self.assertEqual("test-package (%s) %s; urgency=low\n" % (new_version_0_9, os_codename), lines[0])
+        self.assertEqual("test-package (%s) %s; urgency=medium\n" % (new_version_0_9, os_codename), lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
 
@@ -324,7 +324,7 @@ class TestScriptDch(DebianGitTestRepo):
         self.repo.delete_tag("upstream/1.0")
         options = ["--auto"]
         lines = self.run_dch(options)
-        self.assertEqual("test-package (%s) UNRELEASED; urgency=low\n" % new_version_0_9, lines[0])
+        self.assertEqual("test-package (%s) UNRELEASED; urgency=medium\n" % new_version_0_9, lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
 
@@ -345,7 +345,7 @@ class TestScriptDch(DebianGitTestRepo):
         self.repo.delete_tag("upstream/1.0")
         options = ["--auto",  "--release"]
         lines = self.run_dch(options)
-        self.assertEqual("test-package (%s) %s; urgency=low\n" % (new_version_0_9, os_codename), lines[0])
+        self.assertEqual("test-package (%s) %s; urgency=medium\n" % (new_version_0_9, os_codename), lines[0])
         self.assertIn("""  * added debian/control\n""", lines)
 
 
